@@ -19,9 +19,11 @@ extern void ButtonBar_Build (void)
     int h, j, w ;
     int width, height ;
     GC imgOp ;
+    GC maskOp ;
     XGCValues gc ;
     Pixmap image, mask ;
     int x, y ;
+    int x0, y0 ;
     XSetWindowAttributes wa ;
 
     n = Menu_GetNbEntries () ;
@@ -40,34 +42,76 @@ extern void ButtonBar_Build (void)
         width, height, DADepth) ;
     imgOp = XCreateGC (DADisplay, ButtonBarWindow, 0, & gc) ;
 
+    HighlightBehindMask = XCreatePixmap (DADisplay, ButtonBarWindow,
+	width, height, 1) ;
+    maskOp = XCreateGC (DADisplay, HighlightBehindMask, 0, & gc) ;
+
     /* first apply tile to whole bar */
     for (i=0; i<w; i++)
         for (j=0; j<h; j++)
             XCopyArea (DADisplay, TileImage, ButtonBarImage, imgOp, 0, 0,
                 TileXSize, TileYSize, TileXSize*i, TileYSize*j) ;
 
+    /* initialize "behind" mask to all 1's */
+    XSetFunction (DADisplay, maskOp, GXset) ;
+    XFillRectangle (DADisplay, HighlightBehindMask, maskOp,
+	0, 0, width, height) ;
+    /* and copy behind mask cells from highlight mask */
+    if (HighlightMask != 0)
+    {
+	XSetFunction (DADisplay, maskOp, GXcopy) ;
+	for (i=0; i<w; i++)
+	    for (j=0; j<h; j++)
+		XCopyArea (DADisplay, HighlightMask, HighlightBehindMask,
+		    maskOp,
+		    0, 0, TileXSize, TileYSize, TileXSize*i, TileYSize*j) ;
+    }
+
     /* then apply each pixmap of menu entry */
+    /* and build a global invert mask for highlight "behind" */
     for (i=0; i<n; i++)
     {
         Pixmaps_FindLoad (Menu_GetEntryPixmap (i),
             & image, & mask, & width, & height) ;
 
+	/* center pixmap within its cell */
         x = (width >= TileXSize ? 0 : (TileXSize-width)/2) ;
         y = (height >= TileYSize ? 0 : (TileYSize-height)/2) ;
-        gc.clip_x_origin = TileXSize*(i/h) + x ;
-        gc.clip_y_origin = TileYSize*(i%h) + y ;
+
+	/* use GC to draw with pixmap's mask in the right cell */
+	x0 = TileXSize*(i/h) ;
+	y0 = TileYSize*(i%h) ;
+        gc.clip_x_origin = x0 + x ;
+        gc.clip_y_origin = y0 + y ;
         gc.clip_mask = mask ; /* may be None */
         XChangeGC (DADisplay, imgOp,
             GCClipXOrigin | GCClipYOrigin | GCClipMask, & gc) ;
-
         XCopyArea (DADisplay, image, ButtonBarImage, imgOp, 0, 0,
             width, height, gc.clip_x_origin, gc.clip_y_origin) ;
 
+	/* update highlight behind mask: cell &= ~iconmask */
+	if (HighlightBehind && mask != None)
+	{
+	    /* use "andInverted" (dst &= ~src) */
+	    XSetFunction (DADisplay, maskOp, GXandInverted) ;
+	    XCopyArea (DADisplay, mask, HighlightBehindMask, maskOp,
+		0, 0, width, height, gc.clip_x_origin, gc.clip_y_origin) ;
+	}
+	/* or highlight behind cell &= 0 if no mask */
+	else
+	if (HighlightBehind && mask == None)
+	{
+	    XSetFunction (DADisplay, maskOp, GXclear) ;
+	    XFillRectangle (DADisplay, HighlightBehindMask, maskOp,
+		gc.clip_x_origin, gc.clip_y_origin, width, height) ;
+	}
+
         XFreePixmap (DADisplay, image) ;
         if (mask != 0) XFreePixmap (DADisplay, mask) ;
     }
 
     XFreeGC (DADisplay, imgOp) ;
+    XFreeGC (DADisplay, maskOp) ;
 
     wa.background_pixmap = ButtonBarImage ;
     wa.event_mask = ButtonPressMask | ButtonReleaseMask ;
@@ -138,7 +182,7 @@ extern void ButtonBar_Show (void)
 static void BuildHighlightGC (void)
 {
     XGCValues gc ;
-    gc.clip_mask = HighlightMask ;
+    gc.clip_mask = HighlightBehindMask ;
     HighlightGC = XCreateGC (DADisplay, DAWindow,
 	GCClipMask, & gc) ;
 }
@@ -163,8 +207,8 @@ extern void ButtonBar_Highlight (int col, int row)
 	y = row * TileYSize ;
 	/* and draw it */
 	if (HighlightGC == 0) BuildHighlightGC () ;
-        gc.clip_x_origin = x ;
-        gc.clip_y_origin = y ;
+	gc.clip_x_origin = HighlightBehind ? 0 : x ;
+	gc.clip_y_origin = HighlightBehind ? 0 : y ;
         XChangeGC (DADisplay, HighlightGC,
             GCClipXOrigin | GCClipYOrigin, & gc) ;
         XCopyArea (DADisplay, HighlightImage, ButtonBarWindow,
