@@ -41,6 +41,7 @@ char * HighlightPath = MyHighlightPath ;
 bool NewLeaving = true ;
 bool ClickOnly = false ;
 bool AutoScale = true ;
+bool HighlightBehind = false ;
 
 int Options_Argc = 0 ;
 char * Options_Argv [MAXOPTIONS] ;
@@ -57,9 +58,12 @@ static void Usage (void)
 "-O click       bar is only triggered by clicks on the tile, not moves\n"
 "-O oldleaving  hide bar when leaving bar but not tile\n"
 "-O noautoscale disable automatic pixmap scaling to tile size\n"
+"-O behind      draw highlight pixmap behind icon, not above\n"
 "-r ROWS        set number of menu rows (default one)\n"
 "-v             print version information\n"
 "-h             print this help message\n"
+"Note:\n"
+"  -t, -l and '-O behind' can also be specified with the defaults file.\n"
 ""
     ) ;
 }
@@ -78,7 +82,20 @@ static void SetGeometry (const char * val)
 
 static void SetTilePath (const char * value)
 {
+    char *ptrToFree = NULL ;
+
+    if (value != NULL && value[0] == '!')
+    {
+	ptrToFree = File_ReadOutputFromCommand (value+1) ;
+
+	if ((value = ptrToFree) == NULL)
+	    value = "" ;
+    }
+
     sprintf (MyTilePath, "%.*s", (int)(sizeof MyTilePath)-1, value) ;
+
+    if (ptrToFree != NULL)
+	free (ptrToFree) ;
 }
 
 static void SetHighlightPath (const char * value)
@@ -159,6 +176,11 @@ static void ParseDefaults (char * text)
 	    {
 		SetHighlightPath (value) ;
 	    }
+	    else
+	    if (streq (name, "highlight_behind"))
+	    {
+		HighlightBehind = true ;
+	    }
             else error ("unknown setting \"%s\"", name) ;
 
             break ;
@@ -220,7 +242,7 @@ extern void Options_Parse (int argc, char ** argv)
             break ;
 
         case 't' :
-            sprintf (MyTilePath, "%.*s", (int)(sizeof MyTilePath)-1, optarg) ;
+	    SetTilePath (optarg) ;
             break ;
 
 	case 'l' :
@@ -232,6 +254,7 @@ extern void Options_Parse (int argc, char ** argv)
             if (streq (optarg, "oldleaving")) NewLeaving = false ;
             else if (streq (optarg, "click")) ClickOnly = true ;
             else if (streq (optarg, "noautoscale")) AutoScale = false ;
+	    else if (streq (optarg, "behind")) HighlightBehind = true ;
             else printf ("ignoring unknown feature \"%s\"\n", optarg) ;
             break ;
 
@@ -254,7 +277,7 @@ extern void Options_Parse (int argc, char ** argv)
     if (MenuName[0] == EOS)
         error ("no menu file name specified") ;
     if (MyTilePath[0] == EOS)
-        error ("no tile pixmap specified") ;
+        warn ("no tile pixmap specified, using internal default") ;
 
     while (optind < argc && Options_Argc < MAXOPTIONS)
         Options_Argv[Options_Argc++] = argv[optind++] ;
